This branch contains the GitHub Pages for PyOpenGLV4.

These pages are generated by the Sphinx tool (http://sphinx-doc.org) using the
tools/generate-rst-api.sh script from the sources and then the update.sh script to fix them suitable
for github pages.

.. End
